pub enum Error {
Range,
Inexact,
}Expand description
Error types for conversions
Variants
Range
Source value lies outside of target type’s range
This error indicates that the input value is outside the range (domain) of the target type. More precisely, all values of the target type’s domain are either incomparable to the source value or are closer to another value within the target type’s domain than to the source value.
As typical example, attempting to convert -1_i8 to u8 results in a
Range error. A special case is f32::NAN which, being (literally)
“Not a Number” is outside the domain of the target type and thus a
Range error (even where the target type has its own NAN value).
Inexact
Loss of precision
This error indicates that, though the input value is inside the range (domain) of the target type, conversion without loss of precision is impossible.
For example, attempting to convert 2.1_f32 to i32 without rounding
results in an Inexact error.