Nearest

Struct Nearest 

pub struct Nearest;
Available on crate features libm or std only.
Round to the nearest representable value

The precise behaviour of half-way cases is implementation-defined. Provided implementations follow common practices: float-to-int conversions use the round() inherent function which rounds away from zero while int-to-float conversions follow the behaviour of as numeric casts which rounds ties to even.

Example: 2.5_f32 converts to 3_i32, -2.5_f32 converts to -3_i32. Another example: converting i32::MAX to f32 rounds up to 231.

The  Limits of approximation as specified by Approx apply.